@@ -129,6 +129,7 @@ extern struct chanuser *getcuptr(char *, char *);
 extern struct state *emptystate(void);
 extern struct server *addnewserver(char *, int, int, int, int, int);
 extern struct server *getserver(void);
+extern struct advert *addnewadvert(char *, char *, char *);
 extern struct maskstruct *addnewmask(char *);
 extern struct maskstruct *addnewpermban(char *, char *);
 extern struct maskstruct *addnewnickbk(char *, char *, char *);
@@ -149,6 +150,8 @@ extern struct topic *edittopic(char *, char *, char *, int);
 extern struct chanuser *getrandomuser(char *);
 extern struct ls_wrapstruct *addnew_ls(struct ls_wrapstruct *, time_t, char *, char *, char *);
 extern time_t lastoff(char *, char *);
+extern void sendadverts(char *, char *, char *);
+extern void deladverts(char *, char *);
 extern void resetparts(char *, char *, char *);
 extern void iamop(char *, int);
 extern void initpubmsgs(char *);
