@@ -264,7 +264,7 @@ int registerconnection()
 	}
 	if(mystate->current_server->registered == OER_REGISTERCONNECTION_STATUS_BEGIN) {
 		oer_debug(OER_DEBUG_INFO, "registerconnection->registering on the server\n");
-		snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "NICK %s\n", mystate->nick);
+		snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "NICK %s\n", (mystate->use_alt_nick) ? mystate->altnick : mystate->nick);
 		oer_debug(OER_DEBUG_INFO, "registerconnection->%s", stringbuffer);
 		if(write(mystate->sockfd, stringbuffer, strlen(stringbuffer)) < 0) {
 			oer_debug(OER_DEBUG_ERROR, "registerconnection->write failed: %s\n", strerror(errno));
