@@ -30,16 +30,19 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <stdarg.h>
 
 #ifdef HAVE_STRINGS_H
-#include <strings.h>
+  #include <strings.h>
 #endif
 
 #include <string.h>
 
 #ifdef HAVE_CRYPT_H
-#include <crypt.h>
+  #include <crypt.h>
+#endif
+
+#ifdef HAVE_CTYPE_H 
+  #include <ctype.h> 
 #endif
 
-#include <ctype.h>
 #include <errno.h>
 #include <unistd.h>
 #include <netdb.h>
@@ -213,6 +216,14 @@ enum OER_DEBUG_LEVELS {
 	OER_DEBUG_FLOOD = 9
 };
 
+enum OER_ADVERT_TYPES {
+	OER_ADVERT_TYPE_LAMERS,
+	OER_ADVERT_TYPE_BOTUSERS_OPS,
+	OER_ADVERT_TYPE_BOTUSERS_ADMINS,
+	OER_ADVERT_TYPE_BOTUSERS_OTHER,
+	OER_ADVERT_TYPE_INVALID
+};
+
 #define numofparams(x) (wordcount(x) - 1)
 
 /* from glib.h */
@@ -292,7 +303,7 @@ enum OER_DEBUG_LEVELS {
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-30, Copyright (C) 2000 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-31, Copyright (C) 2000 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -426,6 +437,13 @@ struct maskstruct {
 	struct maskstruct *next;
 };
 
+struct advert {
+	char type[TINYSTRINGLEN + 1];
+	char *message;
+	struct advert *prev;
+	struct advert *next;
+};
+
 struct server {
 	char serverhost[HOSTLEN + 1];
 	int serverport;
@@ -474,6 +492,7 @@ struct channel {
 	struct botuser *users;
 	struct authed *autheds;
 	struct topic *topics;
+	struct advert *adverts;
 	struct channel *prev;
 	struct channel *next;
 };
@@ -492,6 +511,7 @@ struct state {
 	char prefix;
 	int customuser;
 	int vhost;
+	int use_alt_nick;
 	int sockfd;
 	int loopforever;
 	int newnick;
