@@ -61,7 +61,6 @@ void parseirc(char *serveroutput)
 	char nick[NICKLEN + 1];
 	char nick2[NICKLEN + 1];
 	char target[NICKLEN + 1];
-	char altnick[NICKLEN + 1];
 	char m;
 	struct channel *this;
 	struct chanuser *cu;
@@ -268,10 +267,15 @@ void parseirc(char *serveroutput)
 		return;
 	}
 	if(!strcasecmp(command, "433")) {
+		if(mystate->use_alt_nick) {
+                        oer_debug(OER_DEBUG_INFO, "parseirc(433)->both our primary and secondary nicknames are taken, generating a random nick\n");
+                        snprintf(mystate->nick, NICKLEN, "oer-%d", getrandom(9999));
+                        mystate->use_alt_nick = 0;
+			mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
+                        return;
+                }
 		oer_debug(OER_DEBUG_INFO, "parseirc(433)->our nickname %s is already in use, will try altnick %s\n", mystate->nick, mystate->altnick);
-		strcpy(altnick, mystate->nick);
-		strcpy(mystate->nick, mystate->altnick);
-		strcpy(mystate->altnick, altnick);
+		mystate->use_alt_nick = 1;
 		mystate->current_server->registered = OER_REGISTERCONNECTION_STATUS_BEGIN;
 		return;
 	}
@@ -400,6 +404,9 @@ void parseirc(char *serveroutput)
 		if(amiop(channel) && !kicked && haschanflags(channel, "o") && isop(channel, host)) {
 			addnewmm(channel, mystate->now, "+o", nick);
 		}
+		if(!kicked && haschanflags(channel, "A")) {
+			sendadverts(channel, nick, host);
+		}
 		if(lastquote(channel) < OER_QUOTE_INTERVAL) {
 			return;
 		}
@@ -637,7 +644,7 @@ void parseirc(char *serveroutput)
 				changeuser(channel, target, -1, -1, 0);
 				break;
 			case OER_NTHMODE_BAN:
-				snprintf(outstring, STRINGLEN, "%s!%s@%s", mystate->nick, mystate->user, mystate->host);
+				snprintf(outstring, STRINGLEN, "%s!%s@%s", (mystate->use_alt_nick) ? mystate->altnick : mystate->nick, mystate->user, mystate->host);
 				if(wild_match(target, outstring)) {
 					oer_debug(OER_DEBUG_INFO, "parseirc(MODE)->ban detected on me (%s)\n", target);
 					if(isq(nick)) {
